@@ -18,29 +18,9 @@
 
 
 
-
-#' Pipe an object forward into a function call/expression.
+#' @importFrom magrittr %>%
 #' @export
-#' @rdname pipe
-#' @param lhs The value to be piped
-#' @param rhs A function or expression
-#' @source
-#' This is just the imported function 
-#' from the magrittr package. The documentation you should
-#' read for the \%>\% function can be found here: \link[magrittr]{pipe}
-#' 
-#' Adding the function in the package while importing it 
-#' is a trick taken from the {dplyr} package
-#' (in the file chain.r)
-#' 
-#' The package could have also been placed in "Depends",
-#' But I wanted to keep it robust if at some point some other 
-#' package will try to take over the symbol (not likely, but still).
-#' 
-#' @seealso 
-#' \link[magrittr]{pipe}
-`%>%` <- magrittr::`%>%`
-
+magrittr::`%>%`
 
 
 # For making this decision, I followed the text from:
